@@ -151,8 +151,6 @@ class WorkbenchRenderer(DataExportRenderer):
 
 
 # Unit test: Create the class, the proper input and run the execute() method for a test
-import pytest
-@pytest.mark.rekall
 def test():
     ''' rekall_adapter.py: Test '''
 
